.. _prima:

===========
Lino Prima
===========

Welcome to the **Lino Prima** project homepage.


Content
========

.. toctree::
   :maxdepth: 1

   get/index
   guide/index
   topics/index
   plugins/index
   api/index
   changes
